# Facebooker
 An unofficial facebook api
 <br>
 <img src="./logo.png" width="200">
## Requirement
- [ ] python3.6

## Dependencies
- [ ] lxml
- [ ] requests
- [ ] bs4
- [ ] requests_toolbelt
### Install
```
$ pip install Facebooker
```

## Document
see [doc.md](https://github.com/gpwork4u/Facebooker/blob/master/doc.md)

